@@ -46,7 +46,7 @@ static int bitpix = 0;	/* number of bits per pixel (FITS code) */
 static int fitsout = 0;	/* Output FITS file from IRAF input if 1 */
 static int nsplit = 0;	/* Output multiple FITS files from n-extension file */
 static int overwrite = 0;	/* allow overwriting of input image file */
-static char *RevMsg = "IMROT WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "IMROT WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 static int version = 0;		/* If 1, print only program name and version */
 static int xshift = 0;
 static int yshift = 0;
@@ -100,7 +100,7 @@ char **av;
 	    }
 
 	/* Set image shifts */
-	else if (isnum (str)) {
+	else if (isnum (str) > 0 && isnum (str) < 2) {
 	    if (shifted) {
 		dy = atof (str);
 		if (dy < 0)
