@@ -1,9 +1,9 @@
 /* File cphead.c
- * March 3, 2015
+ * June 24, 2016
  * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 2000-2015
+   Copyright (C) 2000-2016
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -41,7 +41,7 @@ static void CopyValues();
 extern char *GetFITShead();
 
 static int verbose = 0;		/* verbose/debugging flag */
-static char *RevMsg = "CPHEAD WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "CPHEAD WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 static int copyall = 0;		/* Copy entire header, overwriting old one */
 static int nfile = 0;
 static int ndec0 = -9;
@@ -137,7 +137,7 @@ char **av;
 		    break;
 	
 		case 'w': /* Copy entire WCS */
-		    nkwd1 = 87;
+		    nkwd1 = 236;
 		    if (nkwd + nkwd1 > maxnkwd) {
 			maxnkwd = nkwd + nkwd1 + 32;
 			kwdnew = (char **) calloc (maxnkwd, sizeof (void *));
@@ -148,7 +148,7 @@ char **av;
 			free (kwd);
 			kwd = kwdnew;
 			}
-		    for (ikwd = nkwd; i < nkwd+nkwd1; i++) {
+		    for (ikwd = nkwd; i < nkwd+nkwd1+32; i++) {
 			kwd[ikwd] = (char *) calloc (32, 1);
 			}
 		    strcpy (kwd[nkwd], "RA");
@@ -706,4 +706,6 @@ char	*kwd[];		/* Names of keywords for which to copy values */
  * Sep  1 2011	Fix overflow bug by increasing size of history from 72 to 128
  *
  * Mar  3 2015	Only free headout if it is different from header
+ *
+ * Jun 24 2016	Increase number of keywords to handle distortion polynomials
  */
