@@ -1,9 +1,9 @@
 /* File getcol.c
- * December 10, 2015
+ * June 9, 2016
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1999-2015
+   Copyright (C) 1999-2016
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@
 #define MAXFILES	2000
 #define MAXLINES	100000
 
-static char *RevMsg = "GETCOL WCSTools 3.9.3, 08 June 2016, Jessica Mink SAO";
+static char *RevMsg = "GETCOL WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static void usage();
 static int ListFile();
@@ -211,7 +211,7 @@ char **av;
 	    }
 
 	/* Negative numbers aren't ranges, but positive ones are */
-	else if (isnum (*av)) {
+	else if (isnum (*av) == 1) {
 	    if (ranges) {
 		newbytes = strlen(ranges) + strlen(*av) + 2;
 		newbytes = ((newbytes / 16) + 1) * 16;
@@ -370,7 +370,7 @@ char **av;
 		    lfile = *++av + 1;
 		    ac--;
 		    }
-		else if (isrange (*(av+1)) || isnum (*(av+1))) {
+		else if (isrange (*(av+1)) || isnum (*(av+1)) == 1) {
 		    lranges = (char *) calloc (strlen(*av) + 1, 1);
 		    strcpy (lranges, *++av);
 		    ac--;
@@ -442,7 +442,7 @@ char **av;
 		sop2[i] = (char) 0;
 	    strncpy (sop1, cop[nop], lc[nop]);
 	    strcpy (sop2, op[nop]+1);
-	    if (isnum (sop1) && isnum (sop2)) {
+	    if (isnum (sop1) == 1 && isnum (sop2) == 1) {
 		if (verbose)
 		    printf (" Column %s %c %s\n", sop1, opi[0], sop2);
 		nop++;
@@ -1197,12 +1197,12 @@ char	*lfile;		/* Name of file with lines to list */
 			    token[j] = (char) 0;
 			}
 		    strfix (token, 0, 1);
-		    if (isnum (token)) {
+		    if (isnum (token) > 0 && isnum (token) < 2) {
 			dval = atof (token);
 			hms[i] = 0;
 			idnum = 1;
 			}
-		    else if (strchr (token, ':')) {
+		    else if (isnum (token) == 3) {
 			dval = str2dec (token);
 			hms[i] = 1;
 			idnum = 1;
@@ -1290,7 +1290,7 @@ char	*lfile;		/* Name of file with lines to list */
 		for (j = 0; j< 16; j++)
 		    colstr[j] = (char) 0;
 		strncpy (colstr, cop[iop], lc[iop]);
-		if (isnum (colstr) > 1) {
+		if (isnum (colstr) == 2) {
 		    dnum = atof (colstr);
 		    ndnum = numdec (colstr);
 		    }
@@ -1831,4 +1831,6 @@ void *pd1, *pd2;
  * Nov 19 2015	Add test <col>=n[0][1][2][3][4] to check for numericness
  *
  * Dec 10 2015	Fix tests
+ *
+ * Jun  9 2016	Fix isnum() tests for added coloned times and dashed dates 
  */
