@@ -1,9 +1,9 @@
 /* File getfits.c
- * September 17, 2013
+ * June 24, 2016
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 2002-2013
+   Copyright (C) 2002-2016
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -43,7 +43,7 @@ static void nextname();	/* Find next available name (namea, nameb, ...) */
 static int ExtractFITS();
 
 static int verbose = 0;		/* verbose/debugging flag */
-static char *RevMsg = "GETFITS WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETFITS WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 static int version = 0;		/* If 1, print only program name and version */
 static char outname[128];	/* Name for output image */
 static char outdir[256];	/* Output directory pathname */
@@ -108,6 +108,7 @@ char **av;
 		usage ("Right ascension given but no declination");
 	    else {
 		strcpy (rastr, *av);
+		ac--;
 		strcpy (decstr, *++av);
 		ra0 = str2ra (rastr);
 		dec0 = str2dec (decstr);
@@ -209,7 +210,7 @@ char **av;
 		    ac--;
 		    if (ac > 1) {
 			nextarg = *(av+1);
-			if (isnum (nextarg)) {
+			if (isnum (nextarg) == 1) {
 			    ydpix = atoi (nextarg);
 			    av++;
 			    ac--;
@@ -750,4 +751,7 @@ char *newname;
  *
  * Jan 22 2012	Print error, not blank file, if requested region is off image
  * Sep 17 2013	Include fitswcs.h
+ *
+ * Jun  9 2016	Fix isnum() tests for added coloned times and dashed dates
+ * Jun 24 2016	Decrement argument counter after reading center RA
  */
