@@ -40,7 +40,7 @@ static void usage();
 static void PrintValues();
 static int maxncond = 100;
 
-static char *RevMsg = "GETTAB WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETTAB WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int nfile = 0;
