@@ -1,9 +1,9 @@
 /* File imcat.c
- * May 13, 2015
+ * June 24, 2016
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1996-2015
+   Copyright (C) 1996-2016
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -64,7 +64,7 @@ extern void setdateobs();
 extern void setparm();
 extern void setnpix();
 
-static char *RevMsg = "WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "IMCAT WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int wfile = 0;		/* True to print output file */
@@ -1776,9 +1776,7 @@ char	**refcatname;	/* reference catalog name */
 		    strcat (headline, temp);
 		    }
 		if (refcat == UCAC2 || refcat == UCAC3 || refcat == UCAC4) {
-		    nim = gc[i] / 1000;
-		    nct = gc[i] % 1000;
-		    sprintf (temp, "  ni  nc", nim, nct);
+		    sprintf (temp, "  ni  nc");
 		    strcat (headline, temp);
 		    }
 		else if (gcset)
@@ -2483,4 +2481,6 @@ double	*decmin, *decmax;	/* Declination limits in degrees (returned) */
  * Jul  2 2014	Add UCAC4 catalog
  *
  * May 13 2015	Print two decimal place, not integer, pixel coordinates
+ *
+ * Jun 24 2016	Fix typo in UCAC output format
  */
