@@ -1,9 +1,9 @@
 /* File imstar.c
- * May 13, 2015
+ * June 24, 2016
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1996-2015
+   Copyright (C) 1996-2016
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -41,7 +41,7 @@
 #define MAXFILES 1000
 static int maxnfile = MAXFILES;
 
-static char *RevMsg = "IMSTAR WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "IMSTAR WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose flag */
 static int debug = 0;		/* debugging flag */
@@ -818,7 +818,7 @@ char	*filename;	/* FITS or IRAF file filename */
 	    sprintf (headline, "%7.2f %7.2f %6.2f  %d",
 		    sx[i],sy[i],smag[i],sp[i]);
 	    if (iswcs (wcs))
-		sprintf (headline, "%s %s %s", headline, rastr, decstr);
+		sprintf (headline+strlen(headline), " %s %s", rastr, decstr);
 	    if (wfile)
 		fprintf (fd, "%s\n", headline);
 	    else
@@ -827,14 +827,11 @@ char	*filename;	/* FITS or IRAF file filename */
 	else {
 	    sprintf (headline, "%3d %s %s %6.2f", i+1,rastr,decstr,smag[i]);
 	    if (wcs->nxpix < 100.0 && wcs->nypix > 100.0)
-		sprintf (headline, "%s  %5.2f %5.2f %d",
-		headline, sx[i],sy[i], sp[i]);
+		sprintf (headline+strlen(headline), " %5.2f %5.2f %d", sx[i],sy[i], sp[i]);
 	    else if (wcs->nxpix < 1000.0 && wcs->nypix < 1000.0)
-		sprintf (headline, "%s  %6.2f %6.2f %d",
-		headline, sx[i],sy[i], sp[i]);
+		sprintf (headline+strlen(headline), " %6.2f %6.2f %d", sx[i],sy[i], sp[i]);
 	    else
-		sprintf (headline, "%s  %7.2f %7.2f %d",
-		headline, sx[i],sy[i], sp[i]);
+		sprintf (headline+strlen(headline), " %7.2f %7.2f %d", sx[i],sy[i], sp[i]);
 	    if (wfile)
 		fprintf (fd, "%s\n", headline);
 	    else
@@ -946,4 +943,6 @@ char	*filename;	/* FITS or IRAF file filename */
  * Oct 15 2007	Add -c option to print total flux in counts
  *
  * May 13 2015	Print two decimal place, not integer, pixel coordinates
+ *
+ * Jun 24 2016	Fix sprintf of headline after Ole Streicher
  */
