@@ -1,5 +1,5 @@
 /*** File libwcs/wcs.c
- *** June 8, 2016
+ *** June 24, 2016
  *** By Jessica Mink, jmink@cfa.harvard.edu
  *** Harvard-Smithsonian Center for Astrophysics
  *** Copyright (C) 1994-2016
@@ -187,7 +187,8 @@ char	*proj;	/* Projection */
 /* Allan Brighton: 28.4.98: for backward compat., remove leading "--" */
     while (proj && *proj == '-')
 	proj++;
-    strcpy (wcs->ptype,proj);
+    strncpy (wcs->ptype,proj, 3);
+    wcs->ptype[3] = (char) 0;
     strcpy (wcs->ctype[0],"RA---");
     strcpy (wcs->ctype[1],"DEC--");
     strcat (wcs->ctype[0],proj);
@@ -389,24 +390,30 @@ char	*ctype2;	/* FITS WCS projection for axis 2 */
 	strncpy (ctype1, "XLON",4);
 
     strcpy (wcs->ctype[0], ctype1);
-    strcpy (wcs->ptype, ctype1);
+
+    /* This is only to catch special non-standard projections */
+    strncpy (wcs->ptype, ctype1, 3);
+    wcs->ptype[3] = 0;
 
     /* Linear coordinates */
     if (!strncmp (ctype1,"LINEAR",6)) {
 	wcs->prjcode = WCS_LIN;
 	strcpy (wcs->c1type, "LIN");
+	strcpy (wcs->ptype, "LIN");
 	}
 
     /* Pixel coordinates */
     else if (!strncmp (ctype1,"PIXEL",6)) {
 	wcs->prjcode = WCS_PIX;
 	strcpy (wcs->c1type, "PIX");
+	strcpy (wcs->ptype, "PIX");
 	}
 
     /*Detector pixel coordinates */
     else if (strsrch (ctype1,"DET")) {
 	wcs->prjcode = WCS_PIX;
 	strcpy (wcs->c1type, "PIX");
+	strcpy (wcs->ptype, "PIX");
 	}
 
     /* Set up right ascension, declination, latitude, or longitude */
@@ -437,7 +444,7 @@ char	*ctype2;	/* FITS WCS projection for axis 2 */
 	wcs->ptype[1] = ctype1[iproj+1];
 	wcs->ptype[2] = ctype1[iproj+2];
 	wcs->ptype[3] = 0;
-	sprintf (wcs->ctype[0],"%-4s%4s",wcs->c1type,wcs->ptype);
+	sprintf (wcs->ctype[0],"%-4s %3s",wcs->c1type,wcs->ptype);
 	for (i = 0; i < 8; i++)
 	    if (wcs->ctype[0][i] == ' ') wcs->ctype[0][i] = '-';
 
@@ -508,6 +515,7 @@ char	*ctype2;	/* FITS WCS projection for axis 2 */
     else {
 	wcs->prjcode = WCS_LIN;
 	strcpy (wcs->c1type, "LIN");
+	strcpy (wcs->ptype, "LIN");
 	return (0);
 	}
 
@@ -572,10 +580,6 @@ char	*ctype2;	/* FITS WCS projection for axis 2 */
 	if (ctype2[iproj] == '-') iproj = iproj + 1;
 	if (ctype2[iproj] == '-') iproj = iproj + 1;
 	if (ctype2[iproj] == '-') iproj = iproj + 1;
-	wcs->ptype[0] = ctype2[iproj];
-	wcs->ptype[1] = ctype2[iproj+1];
-	wcs->ptype[2] = ctype2[iproj+2];
-	wcs->ptype[3] = 0;
 
 	if (!strncmp (ctype1, "DEC", 3) ||
 	    !strncmp (ctype1+1, "LAT", 3))
@@ -590,7 +594,7 @@ char	*ctype2;	/* FITS WCS projection for axis 2 */
 	    wcs->degout = 0;
 	    wcs->ndec = 3;
 	    }
-	sprintf (wcs->ctype[1],"%-4s%4s",wcs->c2type,wcs->ptype);
+	sprintf (wcs->ctype[1],"%-4s %3s",wcs->c2type,wcs->ptype);
 	for (i = 0; i < 8; i++)
 	    if (wcs->ctype[1][i] == ' ') wcs->ctype[1][i] = '-';
 	}
@@ -665,8 +669,8 @@ double *cd;			/* Rotation matrix, used if not NULL */
 	}
 
     /* Coordinate reference frame, equinox, and epoch */
-    if (!strncmp (wcs->ptype,"LINEAR",6) ||
-	!strncmp (wcs->ptype,"PIXEL",5))
+    if (!strncmp (wcs->ptype,"LIN",3) ||
+	!strncmp (wcs->ptype,"PIX",3))
 	wcs->degout = -1;
 
     wcs->wcson = 1;
@@ -1343,8 +1347,8 @@ double	*height;	/* Height in degrees (returned) */
 	(void) pix2wcs (wcs,xpix,ycpix,&xpos1,&ypos1);
 	xpix = wcs->nxpix + 0.499999;
 	(void) pix2wcs (wcs,xpix,ycpix,&xpos2,&ypos2);
-	if (strncmp (wcs->ptype,"LINEAR",6) &&
-	    strncmp (wcs->ptype,"PIXEL",5)) {
+	if (strncmp (wcs->ptype,"LIN",3) &&
+	    strncmp (wcs->ptype,"PIX",3)) {
 	    *width = wcsdist (xpos1,ypos1,xpos2,ypos2);
 	    }
 	else
@@ -1356,8 +1360,8 @@ double	*height;	/* Height in degrees (returned) */
 	(void) pix2wcs (wcs,xcpix,ypix,&xpos1,&ypos1);
 	ypix = wcs->nypix + 0.5;
 	(void) pix2wcs (wcs,xcpix,ypix,&xpos2,&ypos2);
-	if (strncmp (wcs->ptype,"LINEAR",6) &&
-	    strncmp (wcs->ptype,"PIXEL",5))
+	if (strncmp (wcs->ptype,"LIN",3) &&
+	    strncmp (wcs->ptype,"PIX",3))
 	    *height = wcsdist (xpos1,ypos1,xpos2,ypos2);
 	else
 	    *height = sqrt (((ypos2-ypos1) * (ypos2-ypos1)) +
@@ -2596,7 +2600,7 @@ char **header;	/* Pointer to start of FITS header */
 char *cwcs;	/* Keyword suffix character for output WCS */
 {
     double tnum;
-    int dkwd[100];
+    int dkwd[MAXNKWD];
     int i, maxnkwd, ikwd, nleft, lbuff, lhead, nkwd, nbytes;
     int nkwdw;
     char **kwd;
@@ -2605,7 +2609,7 @@ char *cwcs;	/* Keyword suffix character for output WCS */
     char tstr[80];
 
     /* Allocate array of keywords to be transferred */
-    maxnkwd = 100;
+    maxnkwd = MAXNKWD;
     kwd = (char **)calloc (maxnkwd, sizeof(char *));
     for (ikwd = 0; ikwd < maxnkwd; ikwd++)
 	kwd[ikwd] = (char *) calloc (16, 1);
@@ -3009,4 +3013,6 @@ char *cwcs;	/* Keyword suffix character for output WCS */
  * Oct 19 2012	Drop depwcs; it's in main wcs structure
  *
  * Jun  8 2016	Increase ctype, ctype1, and ctype2 to 16 characters for distortion
+ * Jun 23 2016	Set initial allocation of keyword arrays to MAXNKWD instead of 100 in cpwcs()
+ * Jun 24 2016	wcs->ptype contains only 3-letter projection code
  */
