@@ -12,7 +12,7 @@
 
 extern int   ned_errno;
 static void PrintUsage();
-static char *RevMsg = "SIMPOS 3.9.3, 08 June 2016, Jessica Mink SAO";
+static char *RevMsg = "SIMPOS 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
