@@ -1,9 +1,9 @@
 /* File sumpix.c
- * January 10, 2014
+ * June 9, 2016
  * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1999-2014
+   Copyright (C) 1999-2016
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@ static void usage();
 static void SumPix();
 extern double PhotPix();
 
-static char *RevMsg = "SUMPIX WCSTools 3.9.3, 08 June 2016, Jessica Mink SAO";
+static char *RevMsg = "SUMPIX WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int version = 0;	/* If 1, print only program name and version */
@@ -171,7 +171,7 @@ char **av;
 	    }
 
 	/* Read range in x or y */
-        else if (isnum (*av) || isrange (*av)) {
+        else if (isnum (*av) == 1 || isrange (*av)) {
 	    if (crange == NULL)
 		crange = *av;
 	    else
@@ -837,4 +837,6 @@ char *rrange;	/* Row range string */
  * May 16 2012	Add option h to print headings
  *
  * Jan 10 2014	Add list file with @ as command line option
+ *
+ * Jun  9 2016	Fix isnum() tests for added coloned times and dashed dates
  */
