@@ -51,7 +51,7 @@ static int sizeset = 0;
 static int scaleset = 0;
 static int version = 0;		/* If 1, print only program name and version */
 
-static char *RevMsg = "XY2SKY WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "XY2SKY WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
